@@ -20,6 +20,7 @@
 """Individual discovery rules for translation formats."""
 
 import json
+import re
 from itertools import chain
 
 from ruamel.yaml import YAML
@@ -27,6 +28,8 @@ from ruamel.yaml.error import YAMLError, YAMLFutureWarning
 
 from .base import BaseDiscovery, EncodingDiscovery, MonoTemplateDiscovery
 
+LARAVEL_RE = re.compile(r"=>.*\|")
+
 
 class GettextDiscovery(BaseDiscovery):
     """Gettext PO files discovery."""
@@ -85,6 +88,13 @@ class JoomlaDiscovery(BaseDiscovery):
     mask = "*.ini"
 
 
+class CSVDiscovery(MonoTemplateDiscovery):
+    """CSV files discovery."""
+
+    file_format = "csv"
+    mask = "*.csv"
+
+
 class WebExtensionDiscovery(BaseDiscovery):
     """web extension files discovery."""
 
@@ -164,7 +174,7 @@ class RESXDiscovery(BaseDiscovery):
             base, code, ext = mask[-1].rsplit(".", 2)
             if not self.is_language_code(code):
                 continue
-            mask[-1] = "{0}.*.{1}".format(base, ext)
+            mask[-1] = f"{base}.*.{ext}"
             yield {"filemask": "/".join(mask)}
         yield from super().get_masks()
 
@@ -328,12 +338,26 @@ class SSADiscovery(MonoTemplateDiscovery):
     mask = "*.ssa"
 
 
-class PHPDiscovery(BaseDiscovery):
+class PHPDiscovery(MonoTemplateDiscovery):
     """PHP files discovery."""
 
     file_format = "php"
     mask = "*.php"
 
+    def adjust_format(self, result):
+        if "template" not in result:
+            return
+
+        path = list(self.finder.mask_matches(result["template"]))[0]
+
+        if not hasattr(path, "open"):
+            return
+
+        with self.finder.open(path, "r") as handle:
+            content = handle.read()
+            if "return [" in content and LARAVEL_RE.search(content):
+                result["file_format"] = "laravel"
+
 
 class IDMLDiscovery(MonoTemplateDiscovery):
     """IDML files discovery."""
