@@ -51,6 +51,11 @@ class APITest(DiscoveryTestCase):
                     "new_base": "locales/messages.pot",
                     "name": "translation",
                 },
+                {
+                    "file_format": "po",
+                    "filemask": "test/*.po",
+                    "new_base": "test/messages.pot",
+                },
                 {
                     "file_format": "po",
                     "filemask": "other/locales/*.po",
@@ -151,6 +156,18 @@ class APITest(DiscoveryTestCase):
                     "template": "yaml/en/corrupt.yml",
                     "file_format": "yaml",
                 },
+                {
+                    "file_format": "php",
+                    "filemask": "php/*.php",
+                    "new_base": "php/en.php",
+                    "template": "php/en.php",
+                },
+                {
+                    "file_format": "laravel",
+                    "filemask": "laravel/*.php",
+                    "new_base": "laravel/en.php",
+                    "template": "laravel/en.php",
+                },
             ],
         )
 
