@@ -26,6 +26,7 @@ from .discovery.files import (
     AndroidDiscovery,
     AppStoreDiscovery,
     ARBDiscovery,
+    CSVDiscovery,
     FluentDiscovery,
     GettextDiscovery,
     HTMLDiscovery,
@@ -33,6 +34,7 @@ from .discovery.files import (
     JoomlaDiscovery,
     JSONDiscovery,
     OSXDiscovery,
+    PHPDiscovery,
     QtDiscovery,
     RESXDiscovery,
     TOMLDiscovery,
@@ -312,7 +314,7 @@ class GetttetTest(DiscoveryTestCase):
         )
 
     def test_po_many(self):
-        with open(os.path.join(TEST_DATA, "calibre.txt"), "r") as handle:
+        with open(os.path.join(TEST_DATA, "calibre.txt")) as handle:
             filenames = handle.read().splitlines()
         discovery = GettextDiscovery(self.get_finder(filenames))
         self.assert_discovery(
@@ -824,7 +826,7 @@ class JSONDiscoveryTest(DiscoveryTestCase):
         Based on Cataclysm-DDA, see
         https://github.com/WeblateOrg/translation-finder/issues/54
         """
-        with open(os.path.join(TEST_DATA, "catalysm.txt"), "r") as handle:
+        with open(os.path.join(TEST_DATA, "catalysm.txt")) as handle:
             filenames = handle.read().splitlines()
         discovery = JSONDiscovery(self.get_finder(filenames))
         # This has many false positives, but most of them come from
@@ -1133,3 +1135,35 @@ class HTMLDiscoveryTest(DiscoveryTestCase):
                 },
             ],
         )
+
+
+class CSVDiscoveryTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = CSVDiscovery(self.get_finder(["csv/en.csv", "csv/cs.csv"]))
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "csv/*.csv",
+                    "file_format": "csv",
+                    "template": "csv/en.csv",
+                    "new_base": "csv/en.csv",
+                },
+            ],
+        )
+
+
+class PHPDiscoveryTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = PHPDiscovery(self.get_finder(["test/en.php"]))
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "test/*.php",
+                    "file_format": "php",
+                    "template": "test/en.php",
+                    "new_base": "test/en.php",
+                },
+            ],
+        )
